==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicPolylineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicShapeSeriesBaseDescription } from "./GeographicShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicPolylineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicPolylineSeriesDescription, _super);
    function GeographicPolylineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.dz = null;
        _this.dx = null;
        _this.dy = null;
        _this.du = 0;
        _this.dt = 0;
        _this.d0 = null;
        return _this;
    }
    GeographicPolylineSeriesDescription.prototype.get_type = function () {
        return "GeographicPolylineSeries";
    };
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeStyleSelectorRef", {
        get: function () {
            return this.dz;
        },
        set: function (a) {
            this.dz = a;
            this.e("ShapeStyleSelectorRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeFill", {
        get: function () {
            return this.dx;
        },
        set: function (a) {
            this.dx = a;
            this.e("ShapeFill");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeStroke", {
        get: function () {
            return this.dy;
        },
        set: function (a) {
            this.dy = a;
            this.e("ShapeStroke");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeStrokeThickness", {
        get: function () {
            return this.du;
        },
        set: function (a) {
            this.du = a;
            this.e("ShapeStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeOpacity", {
        get: function () {
            return this.dt;
        },
        set: function (a) {
            this.dt = a;
            this.e("ShapeOpacity");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "styleShapeRef", {
        get: function () {
            return this.d0;
        },
        set: function (a) {
            this.d0 = a;
            this.e("StyleShapeRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicPolylineSeriesDescription.$t = markType(GeographicPolylineSeriesDescription, 'GeographicPolylineSeriesDescription', GeographicShapeSeriesBaseDescription.$);
    return GeographicPolylineSeriesDescription;
}(GeographicShapeSeriesBaseDescription));
export { GeographicPolylineSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/GeographicPolylineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicShapeSeriesBaseDescription } from "./GeographicShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicPolylineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicPolylineSeriesDescription, _super);
    function GeographicPolylineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.f5 = null;
        _this.f3 = null;
        _this.f4 = null;
        _this.f0 = 0;
        _this.fz = 0;
        _this.f6 = null;
        return _this;
    }
    GeographicPolylineSeriesDescription.prototype.get_type = function () {
        return "GeographicPolylineSeries";
    };
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeStyleSelectorRef", {
        get: function () {
            return this.f5;
        },
        set: function (a) {
            this.f5 = a;
            this.g("ShapeStyleSelectorRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeFill", {
        get: function () {
            return this.f3;
        },
        set: function (a) {
            this.f3 = a;
            this.g("ShapeFill");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeStroke", {
        get: function () {
            return this.f4;
        },
        set: function (a) {
            this.f4 = a;
            this.g("ShapeStroke");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeStrokeThickness", {
        get: function () {
            return this.f0;
        },
        set: function (a) {
            this.f0 = a;
            this.g("ShapeStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "shapeOpacity", {
        get: function () {
            return this.fz;
        },
        set: function (a) {
            this.fz = a;
            this.g("ShapeOpacity");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicPolylineSeriesDescription.prototype, "styleShapeRef", {
        get: function () {
            return this.f6;
        },
        set: function (a) {
            this.f6 = a;
            this.g("StyleShapeRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicPolylineSeriesDescription.$t = markType(GeographicPolylineSeriesDescription, 'GeographicPolylineSeriesDescription', GeographicShapeSeriesBaseDescription.$);
    return GeographicPolylineSeriesDescription;
}(GeographicShapeSeriesBaseDescription));
export { GeographicPolylineSeriesDescription };
